@@ -32,9 +32,9 @@ class SentimentDataProcessor(DataProcessor):
         return self._config.data_dir
 
 
-class SentimentTask(TaskBase):
-    def __init__(self):
-        super().__init__()
+class SentimentTask(ExampleTaskBase):
+    def __init__(self, taskArgs: TaskArguments = None):
+        super().__init__(taskArgs)
         super().task_args.model_args.num_labels = 4
 
     def _data_processor(self):
